@@ -5,16 +5,15 @@ import enum
 from abc import abstractmethod
 from contextlib import contextmanager
 from dataclasses import dataclass
-from typing import Callable, Coroutine, Dict, Generator, Iterable, List, Optional
-from typing import Sequence, Tuple, Type, TypeVar, Union
+from typing import Any, Callable, Coroutine, Generator, Iterable, Iterator, Optional
+from typing import Sequence, TypeVar, Union
 
 import urwid
-from dbus_next.message_bus import BaseMessageBus
 from typing_extensions import AsyncIterator, Protocol, runtime_checkable
 
-UrwidText = Union[str, Tuple[str, str], List[Union[str, Tuple[str, str]]]]
+UrwidText = Union[str, tuple[str, str], list[Union[str, tuple[str, str]]]]
 BasicType = Union[int, str, float]
-JsonType = Union[BasicType, List[BasicType], Dict[str, BasicType]]
+JsonType = Union[BasicType, list[BasicType], dict[str, BasicType]]
 
 JT = TypeVar("JT", bound=JsonType)
 
@@ -43,7 +42,7 @@ class StoredSettings(Protocol):
         """
 
     @abstractmethod
-    def get(self, key: str, type: Type[JT], default: JT = None) -> Optional[JT]:
+    def get(self, key: str, type: type[JT], default: JT = None) -> Optional[JT]:
         """Return the settings value for the key.
 
         If value wasn't set yet, or value in settings is of different type
@@ -51,7 +50,7 @@ class StoredSettings(Protocol):
         """
 
     @abstractmethod
-    def getstrict(self, key: str, type: Type[JT]) -> JT:
+    def getstrict(self, key: str, type: type[JT]) -> JT:
         """Return value for the key.
 
         The value must be set and must be not None. Otherwise exception
@@ -176,7 +175,7 @@ class DeviceManager(Protocol):
         all open NMEA streams"""
 
     @abstractmethod
-    def list(self) -> List[Device]:
+    def enumerate(self) -> list[Device]:
         """Enumerate all registred devices."""
 
     @abstractmethod
@@ -290,9 +289,9 @@ class ModalOptions:
     """
 
     align: str
-    width: Union[str, int, Tuple[str, int]]
+    width: Union[str, int, tuple[str, int]]
     valign: str
-    height: Union[str, int, Tuple[str, int]]
+    height: Union[str, int, tuple[str, int]]
     min_width: Optional[int] = None
     min_height: Optional[int] = None
     left: int = 0
@@ -350,9 +349,17 @@ class ScreenManager(Protocol):
     def draw(self) -> None:
         """Force screen redraw."""
 
+    @abstractmethod
+    @contextmanager
+    def suspended(self) -> Iterator[None]:
+        """Context manager that suspends the screen management
+
+        Useful to run shell apps that require full control over the screen.
+        """
+
     @abstractmethod
     def push_activity(
-        self, activity: Activity, palette: Optional[List[Tuple]] = None
+        self, activity: Activity, palette: Optional[list[tuple]] = None
     ) -> None:
         """Push new activity to the activity stack.
 
@@ -436,6 +443,34 @@ class DBusNotAvailableException(Exception):
     pass
 
 
+class AbstractMessageBusIntrospection(Protocol):
+    pass
+
+
+class AbstractMessageBusProxyObject(Protocol):
+    @abstractmethod
+    def get_interface(self, name: str) -> Any:
+        pass
+
+
+class AbstractMessageBus(Protocol):
+    @abstractmethod
+    async def introspect(
+        self, bus_name: str, path: str, timeout: float = 30.0
+    ) -> AbstractMessageBusIntrospection:
+        pass
+
+    @abstractmethod
+    def get_proxy_object(
+        self, bus_name: str, path: str, introspection: Any
+    ) -> AbstractMessageBusProxyObject:
+        pass
+
+    @abstractmethod
+    def export(self, path: str, agent: Any) -> None:
+        pass
+
+
 class OpenVarioOS(Protocol):
     """Operating system abstractions
 
@@ -462,7 +497,7 @@ class OpenVarioOS(Protocol):
         """
 
     @abstractmethod
-    async def run(self, command: str, args: List[str]) -> OSProcess:
+    async def run(self, command: str, args: list[str]) -> OSProcess:
         """Run a system command and return instance, representing a running process"""
 
     @abstractmethod
@@ -478,7 +513,11 @@ class OpenVarioOS(Protocol):
         """Perform a system reboot"""
 
     @abstractmethod
-    async def get_system_bus(self) -> BaseMessageBus:
+    def spawn_shell(self) -> None:
+        """Spawn a system shell"""
+
+    @abstractmethod
+    async def get_system_bus(self) -> AbstractMessageBus:
         """Return system DBUS object
 
         May raise DBusNotAvailableError.
@@ -548,7 +587,7 @@ class AppManager(Protocol):
     """
 
     @abstractmethod
-    def list(self) -> Iterable[AppInfo]:
+    def list_apps(self) -> Iterable[AppInfo]:
         """Return list of all available applications"""
 
     @abstractmethod
@@ -577,7 +616,3 @@ class OpenVarioShell(Protocol):
     os: OpenVarioOS
     devices: DeviceManager
     processes: ProcessManager
-
-    @abstractmethod
-    def quit(self) -> None:
-        """Quit shell"""
