@@ -2,7 +2,7 @@ import argparse
 import asyncio
 import os
 import sys
-from typing import Optional, Tuple
+from typing import Optional
 
 import urwid
 
@@ -57,7 +57,7 @@ def debounce_esc(keys, raw):
     return filtered
 
 
-def startui(ctx: Tuple[OpenvarioShellImpl, Optional[str]]) -> None:
+def startui(ctx: tuple[OpenvarioShellImpl, Optional[str]]) -> None:
     shell, autostart = ctx
     shell.boot()
     shell.screen.push_activity(MainMenuActivity(shell, autostart))
@@ -112,7 +112,11 @@ def run(argv) -> None:
     evl = urwid.AsyncioEventLoop(loop=asyncioloop)
 
     urwidloop = urwid.MainLoop(
-        None, palette=palette, event_loop=evl, input_filter=debounce_esc, pop_ups=True,
+        None,
+        palette=palette,
+        event_loop=evl,
+        input_filter=debounce_esc,
+        pop_ups=True,
     )
 
     screen = ScreenManagerImpl(urwidloop)
