@@ -2,12 +2,12 @@ import asyncio
 import os
 import subprocess
 import sys
-from typing import List
+from typing import Optional
 
 from dbus_next.aio import MessageBus
 from dbus_next.auth import AuthAnnonymous
 from dbus_next.constants import BusType
-from dbus_next.errors import AuthError
+from dbus_next.errors import AuthError, InvalidAddressError
 
 from ovshell import api
 
@@ -29,7 +29,7 @@ class OSProcessImpl(api.OSProcess):
 
 
 class OpenVarioOSImpl(api.OpenVarioOS):
-    _dbus: MessageBus = None
+    _dbus: Optional[MessageBus] = None
 
     def __init__(self) -> None:
         self._dbus_connect_lock = asyncio.Lock()
@@ -46,7 +46,7 @@ class OpenVarioOSImpl(api.OpenVarioOS):
             return fname[1:]
         return fname
 
-    async def run(self, command: str, args: List[str]) -> api.OSProcess:
+    async def run(self, command: str, args: list[str]) -> api.OSProcess:
         proc = await asyncio.create_subprocess_exec(
             self.path(command),
             *args,
@@ -56,7 +56,7 @@ class OpenVarioOSImpl(api.OpenVarioOS):
         )
         return OSProcessImpl(proc)
 
-    async def get_system_bus(self) -> MessageBus:
+    async def get_system_bus(self) -> api.AbstractMessageBus:
         if self._dbus is not None:
             return self._dbus
 
@@ -69,7 +69,7 @@ class OpenVarioOSImpl(api.OpenVarioOS):
                     bus = await MessageBus(
                         bus_type=BusType.SYSTEM, auth=AuthAnnonymous()
                     ).connect()
-            except OSError as e:
+            except (InvalidAddressError, OSError) as e:
                 raise api.DBusNotAvailableException() from e
             self._dbus = bus
 
@@ -85,6 +85,11 @@ class OpenVarioOSImpl(api.OpenVarioOS):
     def restart(self) -> None:
         subprocess.run(["systemctl", "reboot"])
 
+    def spawn_shell(self) -> None:
+        subprocess.run(["clear"])
+        print("Type 'exit' or press Ctrl-D to return to menu.")
+        subprocess.run(["bash", "-l"])
+
 
 class OpenVarioOSSimulator(OpenVarioOSImpl):
     def __init__(self, rootfs: str) -> None:
