@@ -1,9 +1,9 @@
 import asyncio
-from typing import Coroutine, Set
+from typing import Coroutine
 
 
 class ProcessManagerImpl:
-    _tasks: Set[asyncio.Task]
+    _tasks: set[asyncio.Task]
 
     def __init__(self) -> None:
         self._tasks = set()
