@@ -2,11 +2,10 @@ import asyncio
 import os
 from contextlib import contextmanager
 from dataclasses import dataclass
-from typing import Any, Callable, Coroutine, Dict, Generator, Iterable, List, Optional
-from typing import Tuple, Type, TypeVar
+from typing import Any, Callable, Coroutine, Generator, Iterable, Iterator, Optional
+from typing import TypeVar
 
 import urwid
-from dbus_next.message_bus import BaseMessageBus
 
 from ovshell import api
 
@@ -14,13 +13,13 @@ JT = TypeVar("JT", bound=api.JsonType)
 
 
 class AppManagerStub(api.AppManager):
-    _app_infos: List[api.AppInfo]
+    _app_infos: list[api.AppInfo]
 
-    def __init__(self, log: List[str]) -> None:
+    def __init__(self, log: list[str]) -> None:
         self._log = log
         self._app_infos = []
 
-    def list(self) -> Iterable[api.AppInfo]:
+    def list_apps(self) -> Iterable[api.AppInfo]:
         return self._app_infos
 
     def get(self, appid: str) -> Optional[api.AppInfo]:
@@ -40,7 +39,7 @@ class AppManagerStub(api.AppManager):
 
 
 class ExtensionManagerStub(api.ExtensionManager):
-    def __init__(self, log: List[str]) -> None:
+    def __init__(self, log: list[str]) -> None:
         self._log = log
 
     def list_extensions(self) -> Iterable[api.Extension]:
@@ -51,7 +50,7 @@ class DialogStub(api.Dialog):
     def __init__(self, title: str, content: urwid.Widget):
         self.title = title
         self.content = content
-        self.buttons: Dict[str, Callable[[], bool]] = {}
+        self.buttons: dict[str, Callable[[], bool]] = {}
 
     def add_button(self, label: str, handler: Callable[[], bool]) -> None:
         self.buttons[label] = handler
@@ -72,14 +71,14 @@ class TopIndicatorStub:
 
 
 class ScreenManagerStub(api.ScreenManager):
-    _log: List[str]
-    _activities: List[api.Activity]
-    _tasks: List[Tuple[api.Activity, asyncio.Task]]
+    _log: list[str]
+    _activities: list[api.Activity]
+    _tasks: list[tuple[api.Activity, asyncio.Task]]
     _dialog: Optional[DialogStub]
-    _indicators: Dict[str, TopIndicatorStub]
+    _indicators: dict[str, TopIndicatorStub]
     _status: Optional[api.UrwidText]
 
-    def __init__(self, log: List[str]) -> None:
+    def __init__(self, log: list[str]) -> None:
         self._log = log
         self._activities = []
         self._tasks = []
@@ -90,8 +89,12 @@ class ScreenManagerStub(api.ScreenManager):
     def draw(self) -> None:
         self._log.append("Screen redrawn")
 
+    @contextmanager
+    def suspended(self) -> Iterator[None]:
+        yield
+
     def push_activity(
-        self, activity: api.Activity, palette: Optional[List[Tuple]] = None
+        self, activity: api.Activity, palette: Optional[list[tuple]] = None
     ) -> None:
         self._activities.append(activity)
 
@@ -122,7 +125,6 @@ class ScreenManagerStub(api.ScreenManager):
     def remove_indicator(self, iid: str) -> None:
         if iid in self._indicators:
             del self._indicators[iid]
-        pass
 
     def spawn_task(self, activity: api.Activity, coro: Coroutine) -> asyncio.Task:
         task = asyncio.create_task(coro)
@@ -159,7 +161,7 @@ class ScreenManagerStub(api.ScreenManager):
     def stub_get_indicator(self, iid: str) -> Optional[TopIndicatorStub]:
         return self._indicators.get(iid)
 
-    def stub_list_indicators(self) -> List[TopIndicatorStub]:
+    def stub_list_indicators(self) -> list[TopIndicatorStub]:
         return list(self._indicators.values())
 
     def stub_get_status(self) -> Optional[api.UrwidText]:
@@ -167,9 +169,9 @@ class ScreenManagerStub(api.ScreenManager):
 
 
 class StoredSettingsStub(api.StoredSettings):
-    _settings: Dict[str, Optional[api.JsonType]]
+    _settings: dict[str, Optional[api.JsonType]]
 
-    def __init__(self, log: List[str]) -> None:
+    def __init__(self, log: list[str]) -> None:
         self._log = log
         self._settings = {}
 
@@ -179,11 +181,11 @@ class StoredSettingsStub(api.StoredSettings):
     def set(self, key: str, value: Optional[api.JsonType], save: bool = False):
         self._settings[key] = value
 
-    def get(self, key: str, type: Type[JT], default: JT = None) -> Optional[JT]:
+    def get(self, key: str, type: type[JT], default: JT = None) -> Optional[JT]:
         v = self._settings.get(key, default)
         return v if isinstance(v, type) else None
 
-    def getstrict(self, key: str, type: Type[JT]) -> JT:
+    def getstrict(self, key: str, type: type[JT]) -> JT:
         v = self.get(key, type)
         assert v is not None
         return v
@@ -209,19 +211,19 @@ class OSPRocessStub(api.OSProcess):
         return self._returncode
 
 
-class MessageBusIntrospectionStub:
+class MessageBusIntrospectionStub(api.AbstractMessageBusIntrospection):
     def __init__(self, bus_name: str, path: str) -> None:
         self.bus_name = bus_name
         self.path = path
 
 
-class MessageBusProxyObjectStub:
+class MessageBusProxyObjectStub(api.AbstractMessageBusProxyObject):
     def __init__(
         self,
         bus_name: str,
         path: str,
-        introspection: MessageBusIntrospectionStub,
-        impls: Dict[str, Any],
+        introspection: api.AbstractMessageBusIntrospection,
+        impls: dict[str, Any],
     ) -> None:
         self.__bus_name = bus_name
         self.__path = path
@@ -230,12 +232,11 @@ class MessageBusProxyObjectStub:
 
     def get_interface(self, name: str):
         return self.__impls[name]
-        # return MessageBusProxyInterfaceStub(name, self.__impls[name])
 
 
-class MessageBusStub:
-    _impls: Dict[str, Dict[str, Any]]
-    _exported: Dict[str, Any]
+class MessageBusStub(api.AbstractMessageBus):
+    _impls: dict[str, dict[str, Any]]
+    _exported: dict[str, Any]
 
     def __init__(self) -> None:
         self._impls = {}
@@ -247,7 +248,10 @@ class MessageBusStub:
         return MessageBusIntrospectionStub(bus_name, path)
 
     def get_proxy_object(
-        self, bus_name: str, path: str, introspection: MessageBusIntrospectionStub
+        self,
+        bus_name: str,
+        path: str,
+        introspection: api.AbstractMessageBusIntrospection,
     ) -> MessageBusProxyObjectStub:
         return MessageBusProxyObjectStub(
             bus_name, path, introspection, self._impls.get(path, {})
@@ -260,7 +264,7 @@ class MessageBusStub:
         ifaces = self._impls.setdefault(path, {})
         ifaces[iface_name] = impl
 
-    def stub_get_exported(self) -> Dict[str, Any]:
+    def stub_get_exported(self) -> dict[str, Any]:
         return self._exported
 
 
@@ -271,7 +275,7 @@ class OpenVarioOSStub(api.OpenVarioOS):
     _stub_bus: Optional[MessageBusStub] = None
     _stub_bus_connected: "asyncio.Future[MessageBusStub]"
 
-    def __init__(self, log: List[str], rootfs: str) -> None:
+    def __init__(self, log: list[str], rootfs: str) -> None:
         self._log = log
         self._rootfs = rootfs
         self._stub_bus_connected = asyncio.Future()
@@ -289,7 +293,7 @@ class OpenVarioOSStub(api.OpenVarioOS):
 
         return os.path.join(self._rootfs, path[2:])
 
-    async def run(self, command: str, args: List[str]) -> api.OSProcess:
+    async def run(self, command: str, args: list[str]) -> api.OSProcess:
         self._log.append(f"OS: Running {command} {' '.join(args)}")
         return OSPRocessStub(
             self._stub_run_returncode, self._stub_run_stdout, self._stub_run_stderr
@@ -304,6 +308,9 @@ class OpenVarioOSStub(api.OpenVarioOS):
     def restart(self) -> None:
         self._log.append("OS: Restart")
 
+    def spawn_shell(self) -> None:
+        self._log.append("OS: Run shell")
+
     def stub_expect_run(
         self, result: int = 0, stdout: bytes = b"", stderr: bytes = b""
     ) -> None:
@@ -311,7 +318,7 @@ class OpenVarioOSStub(api.OpenVarioOS):
         self._stub_run_stdout = stdout
         self._stub_run_stderr = stderr
 
-    async def get_system_bus(self) -> BaseMessageBus:
+    async def get_system_bus(self) -> api.AbstractMessageBus:
         return await self._stub_bus_connected
 
     def stub_connect_bus(self) -> MessageBusStub:
@@ -326,7 +333,7 @@ class OpenVarioOSStub(api.OpenVarioOS):
 
 
 class NMEAStreamStub(api.NMEAStream):
-    def __init__(self, nmeas: List[api.NMEA]) -> None:
+    def __init__(self, nmeas: list[api.NMEA]) -> None:
         self._nmeas = list(reversed(nmeas))
 
     async def read(self) -> api.NMEA:
@@ -340,10 +347,10 @@ class NMEAStreamStub(api.NMEAStream):
 
 
 class DeviceManagerStub(api.DeviceManager):
-    _devices: List[api.Device]
-    _nmeas: List[api.NMEA]
+    _devices: list[api.Device]
+    _nmeas: list[api.NMEA]
 
-    def __init__(self, log: List[str]) -> None:
+    def __init__(self, log: list[str]) -> None:
         self._log = log
         self._devices = list()
         self._nmeas = list()
@@ -352,14 +359,14 @@ class DeviceManagerStub(api.DeviceManager):
         self._devices.append(device)
         self._log.append(f"Registered device {device.id}")
 
-    def list(self) -> List[api.Device]:
+    def enumerate(self) -> list[api.Device]:
         return self._devices
 
     @contextmanager
     def open_nmea(self) -> Generator[api.NMEAStream, None, None]:
         yield NMEAStreamStub(self._nmeas)
 
-    def stub_add_nmea(self, nmeas: List[api.NMEA]) -> None:
+    def stub_add_nmea(self, nmeas: list[api.NMEA]) -> None:
         self._nmeas.extend(nmeas)
 
     def stub_remove_device(self, devid: str) -> None:
@@ -367,7 +374,7 @@ class DeviceManagerStub(api.DeviceManager):
 
 
 class ProcessManagerStub(api.ProcessManager):
-    def __init__(self, log: List[str]) -> None:
+    def __init__(self, log: list[str]) -> None:
         self._log = log
 
     def start(self, coro: Coroutine) -> asyncio.Task:
@@ -375,7 +382,7 @@ class ProcessManagerStub(api.ProcessManager):
 
 
 class OpenVarioShellStub(api.OpenVarioShell):
-    _log: List[str]
+    _log: list[str]
 
     def __init__(self, fsroot: str) -> None:
         self._log = []
@@ -389,10 +396,7 @@ class OpenVarioShellStub(api.OpenVarioShell):
 
         self._fsroot = fsroot
 
-    def quit(self) -> None:
-        self._log.append("Shell: Quit")
-
-    def get_stub_log(self) -> List[str]:
+    def get_stub_log(self) -> list[str]:
         return self._log
 
     def stub_teardown(self) -> None:
