@@ -92,7 +92,7 @@ class MainMenuActivity(api.Activity):
 
     def _refresh_pinned_apps(self) -> None:
         m_items = []
-        for appinfo in self.shell.apps.list():
+        for appinfo in self.shell.apps.list_apps():
             if not appinfo.pinned:
                 continue
 
@@ -122,11 +122,12 @@ class MainMenuActivity(api.Activity):
 
     def _on_quit(self, w: urwid.Widget) -> None:
         confirm = self.shell.screen.push_dialog(
-            "Shut Down?", urwid.Text("Do you really want to shut down Openvario?"),
+            "Shut Down?",
+            urwid.Text("Do you really want to shut down Openvario?"),
         )
         confirm.add_button("Shut Down", self._on_shutdown)
         confirm.add_button("Restart", self._on_restart)
-        confirm.add_button("Shell", self._on_exit)
+        confirm.add_button("Shell", self._on_shell)
         confirm.add_button("Cancel", lambda: True)
 
     def _on_shutdown(self) -> bool:
@@ -136,8 +137,9 @@ class MainMenuActivity(api.Activity):
         self.shell.os.shut_down()
         return False
 
-    def _on_exit(self) -> bool:
-        self.shell.quit()
+    def _on_shell(self) -> bool:
+        with self.shell.screen.suspended():
+            self.shell.os.spawn_shell()
         return True
 
     def _on_restart(self) -> bool:
@@ -161,7 +163,7 @@ class MainMenuActivity(api.Activity):
         if appinfo is not None:
             return appinfo
 
-        availapps = ", ".join([a.id for a in self.shell.apps.list()])
+        availapps = ", ".join([a.id for a in self.shell.apps.list_apps()])
         print(f"Error: app '{app_id}' does not exist. " f"Available apps: {availapps}")
         return None
 
@@ -179,7 +181,11 @@ class MainMenuActivity(api.Activity):
         )
 
         # Align with main menu
-        return urwid.Padding(counter_pile, width=("relative", 80), align="center",)
+        return urwid.Padding(
+            counter_pile,
+            width=("relative", 80),
+            align="center",
+        )
 
     async def autostart_countdown(self, countdown: int, appinfo: api.AppInfo):
         empty_widget = self.autostart_counter.original_widget
