@@ -3,6 +3,6 @@ def format_size(size: int) -> str:
     # make suffix the same size to keep numbers dot-aligned
     for unit in ["B  ", "KiB", "MiB", "GiB"]:
         if abs(fsize) < 1024.0:
-            return "%3.1f %s" % (fsize, unit)
+            return f"{fsize:3.1f} {unit}"
         fsize /= 1024.0
-    return "%.1f %s" % (fsize, "TiB")
+    return "{:.1f} {}".format(fsize, "TiB")
