@@ -1,14 +1,11 @@
 import os
 
-import pytest
-
 from ovshell import testing
 from ovshell_core import devsim
 
 HERE = os.path.dirname(__file__)
 
 
-@pytest.mark.asyncio
 async def test_run_simulated_device(ovshell: testing.OpenVarioShellStub) -> None:
     # GIVEN
     samplefile = os.path.join(HERE, "samples", "sample.nmea")
@@ -17,12 +14,11 @@ async def test_run_simulated_device(ovshell: testing.OpenVarioShellStub) -> None
     devsim.run_simulated_device(ovshell, samplefile)
 
     # THEN
-    devs = ovshell.devices.list()
+    devs = ovshell.devices.enumerate()
     assert len(devs) == 1
     assert isinstance(devs[0], devsim.SimulatedDeviceImpl)
 
 
-@pytest.mark.asyncio
 async def test_SimulatedDeviceImpl_readline_infinite(
     ovshell: testing.OpenVarioShellStub, monkeypatch
 ) -> None:
